==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/chrome/browser/ui/webui/sync_internals_ui.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_
#define CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_
#pragma once

#include <string>

#include "base/compiler_specific.h"
#include "base/basictypes.h"
#include "chrome/browser/sync/js_event_handler.h"
#include "content/browser/webui/web_ui.h"

namespace browser_sync {
class JsFrontend;
}  // namespace browser_sync

// The implementation for the chrome://sync-internals page.
class SyncInternalsUI : public WebUI, public browser_sync::JsEventHandler {
 public:
  explicit SyncInternalsUI(TabContents* contents);
  virtual ~SyncInternalsUI();

  // WebUI implementation.
  //
  // The following messages are processed:
  //
  // getAboutInfo():
  //   Immediately fires a onGetAboutInfoFinished() event with a
  //   dictionary of sync-related stats and info.
  //
  // All other messages are routed to the sync service if it exists,
  // and dropped otherwise.
  //
  // TODO(akalin): Add a simple isSyncEnabled() message and make
  // getAboutInfo() be handled by the sync service.
  virtual void OnWebUISend(const GURL& source_url,
                           const std::string& name,
                           const ListValue& args) OVERRIDE;

  // browser_sync::JsEventHandler implementation.
  virtual void HandleJsEvent(
      const std::string& name,
      const browser_sync::JsEventDetails& details) OVERRIDE;
  virtual void HandleJsMessageReply(
      const std::string& name,
      const browser_sync::JsArgList& args) OVERRIDE;

 private:
  // Returns the sync service's JsFrontend object, or NULL if the sync
  // service does not exist.
  browser_sync::JsFrontend* GetJsFrontend();

  DISALLOW_COPY_AND_ASSIGN(SyncInternalsUI);
};

#endif  // CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_

==> chromium-browser_14.0.835.202~r103287.orig.tar.bz2: chromium-14.0.835.202~r103287/src/chrome/browser/ui/webui/sync_internals_ui.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_
#define CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_
#pragma once

#include <string>

#include "base/compiler_specific.h"
#include "base/basictypes.h"
#include "chrome/browser/sync/js_event_handler.h"
#include "chrome/browser/ui/webui/chrome_web_ui.h"

namespace browser_sync {
class JsFrontend;
}  // namespace browser_sync

// The implementation for the chrome://sync-internals page.
class SyncInternalsUI : public ChromeWebUI,
                        public browser_sync::JsEventHandler {
 public:
  explicit SyncInternalsUI(TabContents* contents);
  virtual ~SyncInternalsUI();

  // WebUI implementation.
  //
  // The following messages are processed:
  //
  // getAboutInfo():
  //   Immediately fires a onGetAboutInfoFinished() event with a
  //   dictionary of sync-related stats and info.
  //
  // All other messages are routed to the sync service if it exists,
  // and dropped otherwise.
  //
  // TODO(akalin): Add a simple isSyncEnabled() message and make
  // getAboutInfo() be handled by the sync service.
  virtual void OnWebUISend(const GURL& source_url,
                           const std::string& name,
                           const base::ListValue& args) OVERRIDE;

  // browser_sync::JsEventHandler implementation.
  virtual void HandleJsEvent(
      const std::string& name,
      const browser_sync::JsEventDetails& details) OVERRIDE;
  virtual void HandleJsMessageReply(
      const std::string& name,
      const browser_sync::JsArgList& args) OVERRIDE;

 private:
  // Returns the sync service's JsFrontend object, or NULL if the sync
  // service does not exist.
  browser_sync::JsFrontend* GetJsFrontend();

  DISALLOW_COPY_AND_ASSIGN(SyncInternalsUI);
};

#endif  // CHROME_BROWSER_UI_WEBUI_SYNC_INTERNALS_UI_H_
